@@ -1,7 +1,7 @@
 // qsynthMeter.h
 //
 /****************************************************************************
-   Copyright (C) 2004-2008, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2004-2009, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -133,6 +133,11 @@ public:
 	int iec_scale(float dB) const;
 	int iec_level(int iIndex) const;
 
+#ifdef CONFIG_GRADIENT
+	const QPixmap& pixmap() const;
+	void updatePixmap();
+#endif
+
 	// Slot refreshment.
 	void refresh();
 
@@ -178,6 +183,10 @@ private:
 	int     m_levels[LevelCount];
 	QColor  m_colors[ColorCount];
 
+#ifdef CONFIG_GRADIENT
+	QPixmap *m_pPixmap;
+#endif
+
 	// Peak falloff mode setting (0=no peak falloff).
 	int m_iPeakFalloff;
 };
